==> xes-lib-0.1.12.tar.gz: xes-lib-0.1.12/xes/provinces.py <==
sheng = ["北京市", "天津市", "上海市", "重庆市", "河北省", "山西省", "辽宁省", "吉林省", "黑龙江省", "江苏省", "浙江省", "安徽省", "福建省",
         "江西省", "山东省", "河南省", "湖北省", "湖南省", "广东省", "海南省", "四川省", "贵州省", "云南省", "陕西省", "甘肃省", "青海省", "台湾省",
         "内蒙古自治区", "广西壮族自治区", "西藏自治区", "宁夏回族自治区", "新疆维吾尔自治区", "香港特别行政区", "澳门特别行政区"]
Beijing = ["北京市"]
Tianjin = ["天津市"]
Shanghai = ["上海市"]
Chongqing = ["重庆市"]
Hebei = ['石家庄市', '唐山市', '秦皇岛市', '邯郸市', '邢台市', '保定市', '张家口市', '承德市', '沧州市', '廊坊市', '衡水市']
Shanxi = ['大同市', '朔州市', '忻州市', '阳泉市', '吕梁市', '晋中市', '长治市', '晋城市', '临汾市', '运城市']
Liaoning = ['沈阳市', '大连市', '鞍山市', '抚顺市', '本溪市', '丹东市', '锦州市', '营口市', '阜新市', '辽阳市', '盘锦市', '铁岭市', '朝阳市', '葫芦岛市']
Jilin = ['长春市', '吉林市', '四平市', '辽源市', '通化市', '白山市', '松原市', '白城市', '延边朝鲜族自治州']
HLJ = ['哈尔滨市', '齐齐哈尔市', '牡丹江市', '佳木斯市', '大庆市', '鸡西市', '双鸭山市', '伊春市', '七台河市', '鹤岗市', '绥化市', '黑河市', '大兴安岭地区']
Jiangsu = ['南京市', '无锡市 ', '徐州市', '常州市', '苏州市', '南通市', '连云港市', '淮安市', '盐城市', '扬州市', '镇江市', '泰州市', '宿迁市']
Zhejiang = ['杭州市', '宁波市', '温州市', '湖州市', '嘉兴市', '绍兴市', '金华市', '衢州市', '舟山市', '台州市', '丽水市']
Anhui = ['合肥市', '淮北市', '亳州市', '宿州市', '蚌埠市', '阜阳市', '淮南市', '滁州市', '六安市', '马鞍山市', '芜湖市', '宣城市', '铜陵市', '池州市', '安庆市',
         '黄山市']
Fujian = ['福州市', '厦门市', '泉州市', '漳州市', '莆田市', '龙岩市', '三明市', '南平市', '宁德市']
Jiangxi = ['南昌市', '景德镇市', '萍乡市', '九江市', '新余市', '鹰潭市', '赣州市', '吉安市', '宜春市', '抚州市', '上饶市']
Shandong = ['济南市', '青岛市', '淄博市', '枣庄市', '东营市', '烟台市', '潍坊市', '济宁市', '泰安市', '威海市', '日照市', '滨州市', '德州市', '聊城市', '临沂市',
            '菏泽市']
Henan = ['郑州时', '开封市', '洛阳市', '平顶山市', '安阳市', '鹤壁市', '新乡市', '焦作市', '濮阳市', '许昌市', '漯河市', '三门峡市', '南阳市', '商丘市', '信阳市',
         '周口市', '驻马店市']
Hubei = ['武汉市', '黄石市', '十堰市', '宜昌市', '襄阳市', '鄂州市', '荆门市', '孝感市', '荆州市', '黄冈市', '咸宁市', '随州市', '恩施土家族苗族自治州']
Hunan = ['长沙市', '株洲市', '湘潭市', '衡阳市', '邵阳市', '岳阳市', '常德市', '张家界市', '益阳市', '郴州市', '永州市', '怀化市', '娄底市', '湘西土家族苗族自治州']
Guangdong = ['广州市', '深圳市', '佛山市', '东莞市', '中山市', '珠海市', '江门市', '肇庆时', '惠州市', '汕头市', '潮州市', '揭阳市', '汕尾市', '湛江市', '茂名市',
             '阳江市', '韶关市', '清远市', '云浮市', '梅州市', '河源市']
Hainan = ['海口市', '三亚市', '三沙市', '儋州市']
Sichuan = ['成都市', '绵阳市', '自贡市', '攀枝花市', '泸州市', '德阳市', '广元市', '遂宁市', '内江市', '乐山市', '资阳市', '宜宾市', '南充市', '达州市', '雅安市',
           '广安市', '巴中市', '眉山市']
Guizhou = ['贵阳市', '六盘水市', '遵义市安顺市', '铜仁市', '毕节市', '黔南布依族苗族自治州', '黔西南布依族苗族自治州', '贵州黔东南苗族侗族自治州']
Yunnan = ['昆明市', '曲靖市', '玉溪市', '保山市', '昭通市', '丽江市', '普洱市', '临沧市', '楚雄彝族自治州', '红河哈尼族彝族自治州', '文山壮族苗族自治州', '西双版纳傣族自治州',
          '大理白族自治州', '德宏傣族景颇族自治州', '怒江傈僳族自治州', '迪庆藏族自治州']
Shaanxi = ['西安市', '宝鸡市', '咸阳市', ' 铜川市', '渭南市', ' 延安市', '榆林市', '汉中市', '安康市', '商洛市']
Gansu = ['兰州市', '嘉峪关市', '金昌市', '白银市', '天水市', '武威市', '张掖市', '平凉市', '酒泉市', '庆阳市', '定西市', '陇南市', '临夏回族自治州', '甘南藏族自治州']
Qinghai = ['西宁市', '海东市', '海北藏族自治州', '黄南藏族自治州', '海南藏族自治州', '果洛藏族自治州', '玉树藏族自治州', '海西蒙古族藏族自治州']
Taiwan = ['台北市', '新北市', '桃园市', '台中市', '台南市', '高雄市', '基隆市', '新竹市', '嘉义市']
NMG = ['呼和浩特市', '包头市', '乌海市', '赤峰市', '通辽市', '鄂尔多斯市', '呼伦贝尔市', '巴彦淖尔市', '乌兰察布市']
Guangxi = ['南宁市', '柳州市', '桂林市', '梧州市', '北海市', '防城港市', '钦州市', '贵港市', '玉林市', '百色市', '贺州市', '河池市', '来宾市', '崇左市']
Xizang = ['拉萨市', '日喀则市', '昌都市', '林芝市', '山南市', '那曲市']
Ningxia = ['银川市', '石嘴山市', '吴忠市', '固原市', '中卫市']
Xinjiang = ['乌鲁木齐市', '克拉玛依市', '吐鲁番市', '哈密市']
Xianggang = ["香港特别行政区"]
Aomen = ["澳门特别行政区"]


def get_provinces():
    # 获取全国省份和直辖市
    return sheng


def get_cities(input_city):

    if input_city == "北京" or input_city == "北京市":
        return Beijing
    elif input_city == "天津" or input_city == "天津市":
        return Tianjin
    elif input_city == "上海" or input_city == "上海市":
        return Shanghai
    elif input_city == "重庆" or input_city == "重庆市":
        return Chongqing
    elif input_city == "河北" or input_city == "河北省":
        return Hebei
    elif input_city == "山西" or input_city == "山西省":
        return Shanxi
    elif input_city == "辽宁" or input_city == "辽宁省":
        return Liaoning
    elif input_city == "吉林" or input_city == "吉林省":
        return Jilin
    elif input_city == "黑龙江" or input_city == "黑龙江省":
        return HLJ
    elif input_city == "江苏" or input_city == "江苏省":
        return Jiangsu
    elif input_city == "浙江" or input_city == "浙江省":
        return Zhejiang
    elif input_city == "安徽" or input_city == "安徽省":
        return Anhui
    elif input_city == "福建" or input_city == "福建省":
        return Fujian
    elif input_city == "江西" or input_city == "江西省":
        return Jiangxi
    elif input_city == "山东" or input_city == "山东省":
        return Shandong
    elif input_city == "河南" or input_city == "河南省":
        return Henan
    elif input_city == "湖北" or input_city == "湖北省":
        return Hubei
    elif input_city == "湖南" or input_city == "湖南省":
        return Hunan
    elif input_city == "广东" or input_city == "广东省":
        return Guangdong
    elif input_city == "海南" or input_city == "海南省":
        return Hainan
    elif input_city == "四川" or input_city == "四川省":
        return Sichuan
    elif input_city == "贵州" or input_city == "贵州省":
        return Guizhou
    elif input_city == "云南" or input_city == "云南省":
        return Yunnan
    elif input_city == "陕西" or input_city == "陕西省":
        return Shaanxi
    elif input_city == "甘肃" or input_city == "甘肃省":
        return Gansu
    elif input_city == "青海" or input_city == "青海省":
        return Qinghai
    elif input_city == "台湾" or input_city == "台湾省":
        return Taiwan
    elif input_city == "内蒙古" or input_city == "内蒙古自治区":
        return NMG
    elif input_city == "广西" or input_city == "广西壮族自治区":
        return Guangxi
    elif input_city == "西藏" or input_city == "西藏自治区":
        return Xizang
    elif input_city == "宁夏" or input_city == "宁夏回族自治区":
        return Ningxia
    elif input_city == "新疆" or input_city == "新疆维吾尔自治区":
        return Xinjiang
    elif input_city == "香港" or input_city == "香港特别行政区":
        return Xianggang
    elif input_city == "澳门" or input_city == "澳门特别行政区":
        return Aomen
    else:
        return ["输入错误，请输入正确的省份名称"]

==> xes-lib-0.1.24.tar.gz: xes-lib-0.1.24/xes/provinces.py <==
sheng = ["北京市", "天津市", "上海市", "重庆市", "河北省", "山西省", "辽宁省", "吉林省", "黑龙江省", "江苏省", "浙江省", "安徽省", "福建省",
         "江西省", "山东省", "河南省", "湖北省", "湖南省", "广东省", "海南省", "四川省", "贵州省", "云南省", "陕西省", "甘肃省", "青海省", "台湾省",
         "内蒙古自治区", "广西壮族自治区", "西藏自治区", "宁夏回族自治区", "新疆维吾尔自治区", "香港特别行政区", "澳门特别行政区"]
Beijing = ["北京市"]
Tianjin = ["天津市"]
Shanghai = ["上海市"]
Chongqing = ["重庆市"]
Hebei = ['石家庄市', '唐山市', '秦皇岛市', '邯郸市', '邢台市', '保定市', '张家口市', '承德市', '沧州市', '廊坊市', '衡水市']
Shanxi = ['太原市', '大同市', '朔州市', '忻州市', '阳泉市', '吕梁市', '晋中市', '长治市', '晋城市', '临汾市', '运城市']
Liaoning = ['沈阳市', '大连市', '鞍山市', '抚顺市', '本溪市', '丹东市', '锦州市', '营口市', '阜新市', '辽阳市', '盘锦市', '铁岭市', '朝阳市', '葫芦岛市']
Jilin = ['长春市', '吉林市', '四平市', '辽源市', '通化市', '白山市', '松原市', '白城市', '延边朝鲜族自治州']
HLJ = ['哈尔滨市', '齐齐哈尔市', '牡丹江市', '佳木斯市', '大庆市', '鸡西市', '双鸭山市', '伊春市', '七台河市', '鹤岗市', '绥化市', '黑河市', '大兴安岭地区']
Jiangsu = ['南京市', '无锡市 ', '徐州市', '常州市', '苏州市', '南通市', '连云港市', '淮安市', '盐城市', '扬州市', '镇江市', '泰州市', '宿迁市']
Zhejiang = ['杭州市', '宁波市', '温州市', '湖州市', '嘉兴市', '绍兴市', '金华市', '衢州市', '舟山市', '台州市', '丽水市']
Anhui = ['合肥市', '淮北市', '亳州市', '宿州市', '蚌埠市', '阜阳市', '淮南市', '滁州市', '六安市', '马鞍山市', '芜湖市', '宣城市', '铜陵市', '池州市', '安庆市',
         '黄山市']
Fujian = ['福州市', '厦门市', '泉州市', '漳州市', '莆田市', '龙岩市', '三明市', '南平市', '宁德市']
Jiangxi = ['南昌市', '景德镇市', '萍乡市', '九江市', '新余市', '鹰潭市', '赣州市', '吉安市', '宜春市', '抚州市', '上饶市']
Shandong = ['济南市', '青岛市', '淄博市', '枣庄市', '东营市', '烟台市', '潍坊市', '济宁市', '泰安市', '威海市', '日照市', '滨州市', '德州市', '聊城市', '临沂市',
            '菏泽市']
Henan = ['郑州市', '开封市', '洛阳市', '平顶山市', '安阳市', '鹤壁市', '新乡市', '焦作市', '濮阳市', '许昌市', '漯河市', '三门峡市', '南阳市', '商丘市', '信阳市',
         '周口市', '驻马店市']
Hubei = ['武汉市', '黄石市', '十堰市', '宜昌市', '襄阳市', '鄂州市', '荆门市', '孝感市', '荆州市', '黄冈市', '咸宁市', '随州市', '恩施土家族苗族自治州']
Hunan = ['长沙市', '株洲市', '湘潭市', '衡阳市', '邵阳市', '岳阳市', '常德市', '张家界市', '益阳市', '郴州市', '永州市', '怀化市', '娄底市', '湘西土家族苗族自治州']
Guangdong = ['广州市', '深圳市', '佛山市', '东莞市', '中山市', '珠海市', '江门市', '肇庆时', '惠州市', '汕头市', '潮州市', '揭阳市', '汕尾市', '湛江市', '茂名市',
             '阳江市', '韶关市', '清远市', '云浮市', '梅州市', '河源市']
Hainan = ['海口市', '三亚市', '三沙市', '儋州市']
Sichuan = ['成都市', '绵阳市', '自贡市', '攀枝花市', '泸州市', '德阳市', '广元市', '遂宁市', '内江市', '乐山市', '资阳市', '宜宾市', '南充市', '达州市', '雅安市',
           '广安市', '巴中市', '眉山市']
Guizhou = ['贵阳市', '六盘水市', '遵义市安顺市', '铜仁市', '毕节市', '黔南布依族苗族自治州', '黔西南布依族苗族自治州', '贵州黔东南苗族侗族自治州']
Yunnan = ['昆明市', '曲靖市', '玉溪市', '保山市', '昭通市', '丽江市', '普洱市', '临沧市', '楚雄彝族自治州', '红河哈尼族彝族自治州', '文山壮族苗族自治州', '西双版纳傣族自治州',
          '大理白族自治州', '德宏傣族景颇族自治州', '怒江傈僳族自治州', '迪庆藏族自治州']
Shaanxi = ['西安市', '宝鸡市', '咸阳市', ' 铜川市', '渭南市', ' 延安市', '榆林市', '汉中市', '安康市', '商洛市']
Gansu = ['兰州市', '嘉峪关市', '金昌市', '白银市', '天水市', '武威市', '张掖市', '平凉市', '酒泉市', '庆阳市', '定西市', '陇南市', '临夏回族自治州', '甘南藏族自治州']
Qinghai = ['西宁市', '海东市', '海北藏族自治州', '黄南藏族自治州', '海南藏族自治州', '果洛藏族自治州', '玉树藏族自治州', '海西蒙古族藏族自治州']
Taiwan = ['台北市', '新北市', '桃园市', '台中市', '台南市', '高雄市', '基隆市', '新竹市', '嘉义市']
NMG = ['呼和浩特市', '包头市', '乌海市', '赤峰市', '通辽市', '鄂尔多斯市', '呼伦贝尔市', '巴彦淖尔市', '乌兰察布市']
Guangxi = ['南宁市', '柳州市', '桂林市', '梧州市', '北海市', '防城港市', '钦州市', '贵港市', '玉林市', '百色市', '贺州市', '河池市', '来宾市', '崇左市']
Xizang = ['拉萨市', '日喀则市', '昌都市', '林芝市', '山南市', '那曲市']
Ningxia = ['银川市', '石嘴山市', '吴忠市', '固原市', '中卫市']
Xinjiang = ['乌鲁木齐市', '克拉玛依市', '吐鲁番市', '哈密市']
Xianggang = ["香港特别行政区"]
Aomen = ["澳门特别行政区"]


def get_provinces():
    # 获取全国省份和直辖市
    return sheng


def get_cities(input_city):

    if input_city == "北京" or input_city == "北京市":
        return Beijing
    elif input_city == "天津" or input_city == "天津市":
        return Tianjin
    elif input_city == "上海" or input_city == "上海市":
        return Shanghai
    elif input_city == "重庆" or input_city == "重庆市":
        return Chongqing
    elif input_city == "河北" or input_city == "河北省":
        return Hebei
    elif input_city == "山西" or input_city == "山西省":
        return Shanxi
    elif input_city == "辽宁" or input_city == "辽宁省":
        return Liaoning
    elif input_city == "吉林" or input_city == "吉林省":
        return Jilin
    elif input_city == "黑龙江" or input_city == "黑龙江省":
        return HLJ
    elif input_city == "江苏" or input_city == "江苏省":
        return Jiangsu
    elif input_city == "浙江" or input_city == "浙江省":
        return Zhejiang
    elif input_city == "安徽" or input_city == "安徽省":
        return Anhui
    elif input_city == "福建" or input_city == "福建省":
        return Fujian
    elif input_city == "江西" or input_city == "江西省":
        return Jiangxi
    elif input_city == "山东" or input_city == "山东省":
        return Shandong
    elif input_city == "河南" or input_city == "河南省":
        return Henan
    elif input_city == "湖北" or input_city == "湖北省":
        return Hubei
    elif input_city == "湖南" or input_city == "湖南省":
        return Hunan
    elif input_city == "广东" or input_city == "广东省":
        return Guangdong
    elif input_city == "海南" or input_city == "海南省":
        return Hainan
    elif input_city == "四川" or input_city == "四川省":
        return Sichuan
    elif input_city == "贵州" or input_city == "贵州省":
        return Guizhou
    elif input_city == "云南" or input_city == "云南省":
        return Yunnan
    elif input_city == "陕西" or input_city == "陕西省":
        return Shaanxi
    elif input_city == "甘肃" or input_city == "甘肃省":
        return Gansu
    elif input_city == "青海" or input_city == "青海省":
        return Qinghai
    elif input_city == "台湾" or input_city == "台湾省":
        return Taiwan
    elif input_city == "内蒙古" or input_city == "内蒙古自治区":
        return NMG
    elif input_city == "广西" or input_city == "广西壮族自治区":
        return Guangxi
    elif input_city == "西藏" or input_city == "西藏自治区":
        return Xizang
    elif input_city == "宁夏" or input_city == "宁夏回族自治区":
        return Ningxia
    elif input_city == "新疆" or input_city == "新疆维吾尔自治区":
        return Xinjiang
    elif input_city == "香港" or input_city == "香港特别行政区":
        return Xianggang
    elif input_city == "澳门" or input_city == "澳门特别行政区":
        return Aomen
    else:
        return ["输入错误，请输入正确的省份名称"]
